package com.github.htfv.maven.plugins.testing.internal;

import org.codehaus.plexus.PlexusTestCase;

/**
 * Facade for the Plexus container.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class PlexusContainer
{
    /**
     * Plexus container.
     *
     * @author htfv (Aliaksei Lahachou)
     */
    private static class PlexusContainerImpl extends PlexusTestCase
    {
        /**
         * Looks up a component from the container.
         *
         * @param <T>
         *            the type of the component to look up.
         * @param componentClass
         *            the type of the component to look up.
         *
         * @return The component from the container.
         *
         * @throws Exception
         *             if the component could not be looked up.
         */
        public <T> T doLookup(final Class<T> componentClass) throws Exception
        {
            return super.lookup(componentClass);
        }

        /**
         * Tears down the Plexus container.
         *
         * @throws Exception
         *             if the container could not be teared down.
         */
        public void doTearDown() throws Exception
        {
            super.tearDown();
        }
    }

    /**
     * The Plexus container.
     */
    private PlexusContainerImpl impl = new PlexusContainerImpl();

    /**
     * Looks up a component from the container.
     *
     * @param <T>
     *            the type of the component to look up.
     * @param componentClass
     *            the type of the component to look up.
     *
     * @return The component from the container.
     *
     * @throws Exception
     *             if the component could not be looked up.
     */
    public <T> T lookup(final Class<T> componentClass) throws Exception
    {
        return impl.doLookup(componentClass);
    }

    /**
     * Tears down the Plexus container.
     *
     * @throws Exception
     *             if the container could not be teared down.
     */
    public void tearDown() throws Exception
    {
        impl.doTearDown();
    }
}
